searchData={"items":[{"type":"module","title":"Membrane.SRTCP.Decryptor","doc":"Converts SRTCP packets to plain RTCP.\n\nRequires adding [libsrtp](https://github.com/membraneframework/elixir_libsrtp) dependency to work.","ref":"Membrane.SRTCP.Decryptor.html"},{"type":"module","title":"Element options - Membrane.SRTCP.Decryptor","doc":"Passed via struct `t:Membrane.SRTCP.Decryptor.t/0`\n\n- `policies`  \n\n  ```\n  [ExLibSRTP.Policy.t()]\n  ```\n  \n  ***Required***  \n  List of SRTP policies to use for decrypting packets.\n  See `t:ExLibSRTP.Policy.t/0` for details.","ref":"Membrane.SRTCP.Decryptor.html#module-element-options"},{"type":"module","title":"Pads - Membrane.SRTCP.Decryptor","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.SRTCP.Decryptor.html#module-pads"},{"type":"function","title":"Membrane.SRTCP.Decryptor.options/0","doc":"Returns description of options available for this module","ref":"Membrane.SRTCP.Decryptor.html#options/0"},{"type":"type","title":"Membrane.SRTCP.Decryptor.t/0","doc":"Struct containing options for `Membrane.SRTCP.Decryptor`","ref":"Membrane.SRTCP.Decryptor.html#t:t/0"},{"type":"module","title":"Membrane.RTP.SessionBin","doc":"Bin handling one RTP session, that may consist of multiple incoming and outgoing RTP streams.","ref":"Membrane.RTP.SessionBin.html"},{"type":"module","title":"Incoming streams - Membrane.RTP.SessionBin","doc":"Incoming RTP streams can be connected via `:rtp_input` pads. As each pad can provide multiple RTP streams,\nthey are distinguished basing on SSRC. Once a new stream is received, bin sends `t:new_stream_notification_t/0`\nnotification, meaning the parent should link `Pad.ref(:output, ssrc)` pad to consuming components. The stream is\nthen depayloaded and forwarded via said pad.","ref":"Membrane.RTP.SessionBin.html#module-incoming-streams"},{"type":"module","title":"Outgoing streams - Membrane.RTP.SessionBin","doc":"To create an RTP stream, the source stream needs to be connected via `Pad.ref(:input, ssrc)` pad and the sink -\nvia `Pad.ref(:rtp_output, ssrc)`. At least one of `:encoding` or `:payload_type` options of `:rtp_output` pad\nmust be provided too.","ref":"Membrane.RTP.SessionBin.html#module-outgoing-streams"},{"type":"module","title":"Payloaders and depayloaders - Membrane.RTP.SessionBin","doc":"Payloaders are Membrane elements that transform stream so that it can be put into RTP packets, while depayloaders\nwork the other way round. Different codecs require different payloaders and depayloaders.\n\nBy default `SessionBin` will neither payload nor depayload incoming/outgoing streams, to do so a payloader/depayloader needs to be\npassed via `Pad.ref(:input, ssrc)` and `Pad.ref(:output, ssrc)` pads options.\n\nPayloading/Depayloading is necessary if we need to somehow transform the streams. If `SessionBin`s main role is to route packets\nthen depayloading and payloading processes are redundant.\n\nPayloaders and depayloaders can be found in `membrane_rtp_X_plugin` packages, where X stands for codec name.\nIt's enough when such a plugin is added to dependencies. To determine which payloader/depayloader to use, one can use `Membrane.RTP.PayloadFormatResolver`\nwhich given an encoding name should resolve to proper payloader/depayloader modules (if those previously have been registered via mentioned plugins).\n\nFor payloading and depayloading, `SessionBin` uses respective bins `Membrane.RTP.PayloaderBin` and `Membrane.RTP.DepayloaderBin`\nwhich will be spawned once payloader/depayloader are passed explicitly via pads' options.\n\n##","ref":"Membrane.RTP.SessionBin.html#module-payloaders-and-depayloaders"},{"type":"module","title":"Important note - Membrane.RTP.SessionBin","doc":"Payloaders and depayloaders are mostly needed when working with external media sources (in different formats than RTP).\nFor applications such as an SFU it is not needed to either payload or depayload the RTP stream as we are always dealing with RTP format.\nIn such a case, SessionBin will receive payloaded packets and work as a simple proxy just forwarding the packets (and decrypting them if necessary).\nTherefore it is possible to specify in newly added pads if payloaders/depayloaders should be used for the certain stream.","ref":"Membrane.RTP.SessionBin.html#module-important-note"},{"type":"module","title":"Padding - Membrane.RTP.SessionBin","doc":"Addition and removal of a padding from RTP packets is handled by the RTP plugin.\n\nTo send a packet with a padding, one should include `padding_size` field in `Membrane.Buffer`'s metadata.\n\nE.g.\n\n```elixir\nmetadata = %{rtp: %{padding_size: 20}}\n```\n\nwill result in adding 20 bytes of padding at the end of packet's payload.\n\nWhen parsing an RTP stream, a padding is stripped out and the `padding_size` field is set appropriately to the\nnumber of bytes that were removed.\n\nFor more information, please refer to the [RFC 3550, sec. 5](https://www.rfc-editor.org/rfc/rfc3550#section-5)","ref":"Membrane.RTP.SessionBin.html#module-padding"},{"type":"module","title":"RTCP - Membrane.RTP.SessionBin","doc":"RTCP packets for inbound stream can be provided either in-band or via a separate `rtp_input` pad instance. Corresponding\nreceiver report packets will be sent back through `rtcp_receiver_output` with the same id as `rtp_input` for the RTP stream.\n\nRTCP for outbound stream is not yet supported. # But will be :)","ref":"Membrane.RTP.SessionBin.html#module-rtcp"},{"type":"module","title":"Bin options - Membrane.RTP.SessionBin","doc":"Passed via struct `t:Membrane.RTP.SessionBin.t/0`\n\n- `fmt_mapping`  \n\n  ```\n  %{RTP.payload_type_t() => {RTP.encoding_name_t(), RTP.clock_rate_t()}}\n  ```\n  \n  Default value: `%{}`  \n  Mapping of the custom payload types ( > 95)\n\n\n- `rtcp_receiver_report_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  Interval between sending subseqent RTCP receiver reports.\n\n\n\n- `rtcp_sender_report_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  Interval between sending subseqent RTCP sender reports.\n\n\n\n- `receiver_ssrc_generator`  \n\n  ```\n  (local_ssrcs :: [pos_integer], remote_ssrcs :: [pos_integer] -> ssrc :: pos_integer)\n  ```\n  \n  Default value: `&Membrane.RTP.SessionBin.generate_receiver_ssrc/2`  \n  Function generating receiver SSRCs. Default one generates random SSRC\n  that is not in `local_ssrcs` nor `remote_ssrcs`.\n\n\n\n- `secure?`  \n\n  ```\n  any\n  ```\n  \n  Default value: `false`  \n  Specifies whether to use SRTP.\n  Requires adding [srtp](https://github.com/membraneframework/elixir_libsrtp) dependency to work.\n\n\n\n- `srtp_policies`  \n\n  ```\n  [ExLibSRTP.Policy.t()]\n  ```\n  \n  Default value: `[]`  \n  List of SRTP policies to use for decrypting packets. Used only when `secure?` is set to `true`.\n  See `t:ExLibSRTP.Policy.t/0` for details.\n\n\n\n- `receiver_srtp_policies`  \n\n  ```\n  [ExLibSRTP.Policy.t()] | nil\n  ```\n  \n  Default value: `nil`  \n  List of SRTP policies to use for encrypting receiver reports and other receiver RTCP packets.\n  Used only when `secure?` is set to `true`.\n  Defaults to the value of `srtp_policies`.\n  See `t:ExLibSRTP.Policy.t/0` for details.","ref":"Membrane.RTP.SessionBin.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.RTP.SessionBin","doc":"### `:rtp_input`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: cf} when cf in [RTP, RTCP, nil]\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\n\n\n### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nPad options:\n\n- `payloader`  \n\n  ```\n  module() | nil\n  ```\n  \n  Default value: `nil`  \n  Payloader's module that should be used for a media stream flowing through the pad.\n  \n  If set to nil then the payloading process gets skipped.\n\n\n- `rtp_extensions`  \n\n  ```\n  [rtp_extension_options_t()]\n  ```\n  \n  Default value: `[]`  \n  List of RTP extension options. RTP plugin ships with the following extensions for input pad:\n  * `:twcc` (sender) - it will tag outgoing packets with transport-wide sequence numbers and estimate available bandwidth.\n  For input pad, TWCC sender can only be spawned. For more information refer to `Membrane.RTP.TWCCSender` module documentation.\n  \n  There is no possibility to pass user-defined RTP extenions for input pad.\n  \n  Examples:\n  \n  * `{:twcc, Mebrane.RTP.TWCCSender}`\n\n\n\n- `telemetry_label`  \n\n  ```\n  Membrane.TelemetryMetrics.label()\n  ```\n  \n  Default value: `[]`  \n  \n\n\n\n\n\n### `:rtcp_sender_output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: RTCP}\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\n\n\n\n### `:rtcp_receiver_output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: RTCP}\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\n\n\n\n### `:rtp_output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: RTP}\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nPad options:\n\n- `payload_type`  \n\n  ```\n  RTP.payload_type_t() | nil\n  ```\n  \n  Default value: `nil`  \n  Payload type of output stream. If not provided, determined from `:encoding`.\n\n\n- `encoding`  \n\n  ```\n  RTP.encoding_name_t() | nil\n  ```\n  \n  Default value: `nil`  \n  Encoding name of output stream. If not provided, determined from `:payload_type`.\n\n\n\n- `clock_rate`  \n\n  ```\n  integer() | nil\n  ```\n  \n  Default value: `nil`  \n  Clock rate to use. If not provided, determined from `:payload_type`.\n\n\n\n- `rtp_extension_mapping`  \n\n  ```\n  rtp_extension_mapping_t()\n  ```\n  \n  Default value: `nil`  \n  Mapping from locally used `rtp_extension_name_t()` to integer identifiers expected by\n  the receiver of a RTP stream.\n\n\n\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nPad options:\n\n- `depayloader`  \n\n  ```\n  module() | nil\n  ```\n  \n  Default value: `nil`  \n  Depayloader's module that should be used for an outgoing media stream flowing through the pad.\n  \n  If set to nil then the depayloading process gets skipped.\n\n\n- `telemetry_label`  \n\n  ```\n  Membrane.TelemetryMetrics.label()\n  ```\n  \n  Default value: `[]`  \n  Label passed to Membrane.TelemetryMetrics functions\n\n\n\n- `encoding`  \n\n  ```\n  RTP.encoding_name_t() | nil\n  ```\n  \n  Default value: `nil`  \n  \n\n\n\n- `clock_rate`  \n\n  ```\n  integer() | nil\n  ```\n  \n  Default value: `nil`  \n  Clock rate to use. If not provided, determined from `fmt_mapping` or defaults registered by proper plugins i.e.\n  `Membrane.RTP.X.Plugin` where X is the name of codec corresponding to `encoding`.\n\n\n\n- `rtp_extensions`  \n\n  ```\n  [rtp_extension_options_t()]\n  ```\n  \n  Default value: `[]`  \n  List of RTP extension options. RTP plugin ships with the following RTP extensions for output pad:\n  * `:vad` will turn on Voice Activity Detection mechanism firing appropriate notifications when needed.\n  Should be set only for audio tracks. For more information refer to `Membrane.RTP.VAD` module documentation.\n  * `:twcc` (receiver) will gather transport-wide information about received packets and generate feedbacks for sender.\n  For output pad, TWCC receiver can only be spawned. For more information refer to `Membrane.RTP.TWCCReceiver` module documentation.\n  \n  User can also pass its own RTP extensions for output pad.\n  \n  RTP extensions (except `:twcc`) are applied in the same order as passed to the pad options.\n  \n  Examples:\n  \n  * `{:vad, %Mebrane.RTP.VAD{vad_id: 1, time_window: 1_000_000}}`\n  * `{:twcc, %Mebrane.RTP.TWCCReceiver{twcc_id: 1, report_interval: Membrane.Time.milliseconds(250)}}`\n\n\n\n- `extensions`  \n\n  ```\n  [extension_t()]\n  ```\n  \n  Default value: `[]`  \n  A list of general extensions that will be attached to the packets flow (added inside `Membrane.RTP.StreamReceiveBin`).\n  In case of SRTP extensions are placed before the Decryptor. The order of provided elements is important\n  as the extensions are applied in FIFO order.\n  \n  An extension can be responsible e.g. for dropping silent audio packets when encountered VAD extension data in the\n  packet header.","ref":"Membrane.RTP.SessionBin.html#module-pads"},{"type":"function","title":"Membrane.RTP.SessionBin.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.SessionBin.html#options/0"},{"type":"type","title":"Membrane.RTP.SessionBin.extension_t/0","doc":"A definition of a general extension inside `Membrane.RTP.StreamReceiveBin`. Each extension should\nhave just a single input and output pad named accordingly.\n\nExtensions can implement different functionalities, for example a filter can be responsible for dropping silent\naudio packets when encountered VAD extension data in header extensions of a packet.","ref":"Membrane.RTP.SessionBin.html#t:extension_t/0"},{"type":"type","title":"Membrane.RTP.SessionBin.input_pad_opts/0","doc":"Options for pad `:input`","ref":"Membrane.RTP.SessionBin.html#t:input_pad_opts/0"},{"type":"type","title":"Membrane.RTP.SessionBin.new_stream_notification_t/0","doc":"","ref":"Membrane.RTP.SessionBin.html#t:new_stream_notification_t/0"},{"type":"type","title":"Membrane.RTP.SessionBin.output_pad_opts/0","doc":"Options for pad `:output`","ref":"Membrane.RTP.SessionBin.html#t:output_pad_opts/0"},{"type":"type","title":"Membrane.RTP.SessionBin.rtp_extension_mapping_t/0","doc":"A mapping between internally used `rtp_extension_name_t()` and extension identifiers expected by RTP stream receiver.","ref":"Membrane.RTP.SessionBin.html#t:rtp_extension_mapping_t/0"},{"type":"type","title":"Membrane.RTP.SessionBin.rtp_extension_name_t/0","doc":"An atom that identifies an RTP extension in the bin. It will be used by the module implementing it\nto mark its header extension under `Membrane.RTP.Header.Extension`'s `identifier` key.","ref":"Membrane.RTP.SessionBin.html#t:rtp_extension_name_t/0"},{"type":"type","title":"Membrane.RTP.SessionBin.rtp_extension_option_t/0","doc":"A module representing an RTP extension that will be spawned and linked just after a newly created\n`:input` pad or before a newly created `:output` pad representing a single RTP stream.\n\nGiven extension config must be a valid `Membrane.Filter`.\n\nAn extension will be spawned inside the bin under `{extension_name, ssrc}` name.\n\n#","ref":"Membrane.RTP.SessionBin.html#t:rtp_extension_option_t/0"},{"type":"type","title":"RTP plugin ships with the following extensions: - Membrane.RTP.SessionBin.rtp_extension_option_t/0","doc":"* `Membrane.RTP.VAD`\n* `Membrane.RTP.TWCCReceiver`\n* `Membrane.RTP.TWCCSender`\n\n#","ref":"Membrane.RTP.SessionBin.html#t:rtp_extension_option_t/0-rtp-plugin-ships-with-the-following-extensions"},{"type":"type","title":"TWCC - Membrane.RTP.SessionBin.rtp_extension_option_t/0","doc":"TWCC as a transport-wide extension is handled differently, and is linked from `RTP.SSRCRouter`\nto possibly many `RTP.StreamReceiveBin`s. Only the first TWCC extension is initialized, and it\nwill handle all RTP streams that have declared support for it. For outgoing streams, an `RTP.TWCCSender`\nelement will be spawned and linked to all `RTP.StreamSendBin`s.","ref":"Membrane.RTP.SessionBin.html#t:rtp_extension_option_t/0-twcc"},{"type":"type","title":"Membrane.RTP.SessionBin.rtp_extension_options_t/0","doc":"","ref":"Membrane.RTP.SessionBin.html#t:rtp_extension_options_t/0"},{"type":"type","title":"Membrane.RTP.SessionBin.rtp_output_pad_opts/0","doc":"Options for pad `:rtp_output`","ref":"Membrane.RTP.SessionBin.html#t:rtp_output_pad_opts/0"},{"type":"type","title":"Membrane.RTP.SessionBin.t/0","doc":"Struct containing options for `Membrane.RTP.SessionBin`","ref":"Membrane.RTP.SessionBin.html#t:t/0"},{"type":"module","title":"Membrane.RTP.SessionBin.RTXInfo","doc":"A struct used to inform SessionBin about availability of RTX stream\nwith data allowing to set up proper part of a pipeline","ref":"Membrane.RTP.SessionBin.RTXInfo.html"},{"type":"module","title":"Membrane.RTP.DepayloaderBin","doc":"Modules responsible for reordering incoming RTP packets using a jitter buffer\nto later depayload packet's payload from RTP format.","ref":"Membrane.RTP.DepayloaderBin.html"},{"type":"module","title":"Bin options - Membrane.RTP.DepayloaderBin","doc":"Passed via struct `t:Membrane.RTP.DepayloaderBin.t/0`\n\n- `depayloader`  \n\n  ```\n  module()\n  ```\n  \n  ***Required***  \n  Depayloader module that should be used for incoming stream\n\n\n- `clock_rate`  \n\n  ```\n  RTP.clock_rate_t()\n  ```\n  \n  ***Required***","ref":"Membrane.RTP.DepayloaderBin.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.RTP.DepayloaderBin","doc":"### `:input`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:always`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`","ref":"Membrane.RTP.DepayloaderBin.html#module-pads"},{"type":"function","title":"Membrane.RTP.DepayloaderBin.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.DepayloaderBin.html#options/0"},{"type":"type","title":"Membrane.RTP.DepayloaderBin.t/0","doc":"Struct containing options for `Membrane.RTP.DepayloaderBin`","ref":"Membrane.RTP.DepayloaderBin.html#t:t/0"},{"type":"module","title":"Membrane.RTP.Header","doc":"Describes RTP Header defined in [RFC3550](https://tools.ietf.org/html/rfc3550#page-13)\n\n```\n 0                   1                   2                   3\n 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|V=2|P|X|  CC   |M|     PT      |       sequence number         |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|                           timestamp                           |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n|           synchronization source (SSRC) identifier            |\n+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+\n|            contributing source (CSRC) identifiers             |\n|                             ....                              |\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n```","ref":"Membrane.RTP.Header.html"},{"type":"type","title":"Membrane.RTP.Header.marker/0","doc":"The interpretation of the marker is defined by a profile","ref":"Membrane.RTP.Header.html#t:marker/0"},{"type":"type","title":"Membrane.RTP.Header.sequence_number_t/0","doc":"A 16-bit integer sequential number of a packet.\n\nIts initial value should be random.","ref":"Membrane.RTP.Header.html#t:sequence_number_t/0"},{"type":"type","title":"Membrane.RTP.Header.t/0","doc":"","ref":"Membrane.RTP.Header.html#t:t/0"},{"type":"type","title":"Membrane.RTP.Header.timestamp_t/0","doc":"Timestamp of a packet in ticks of clock according to `t:RTP.clock_rate_t/0`.\n\nIts initial value is random, so it should not be interpreted as an absolute time, but rather used to calculate\ntime difference from other timestamps.","ref":"Membrane.RTP.Header.html#t:timestamp_t/0"},{"type":"type","title":"Membrane.RTP.Header.version/0","doc":"This field identifies the version of RTP. The version defined by this specification is 2.","ref":"Membrane.RTP.Header.html#t:version/0"},{"type":"module","title":"Membrane.RTP.Header.Extension","doc":"Describes RTP Header Extension defined in [RFC8285](https://datatracker.ietf.org/doc/html/rfc8285)\nand provides common functions for interacting with extensions placed in buffers.\n\n```\n 0                   1                   2\n 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 ...\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-\n|  ID   |  len  |     data (len+1 bytes)   ...\n+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-\n```","ref":"Membrane.RTP.Header.Extension.html"},{"type":"function","title":"Membrane.RTP.Header.Extension.delete/2","doc":"","ref":"Membrane.RTP.Header.Extension.html#delete/2"},{"type":"function","title":"Membrane.RTP.Header.Extension.find/2","doc":"","ref":"Membrane.RTP.Header.Extension.html#find/2"},{"type":"function","title":"Membrane.RTP.Header.Extension.pop/2","doc":"","ref":"Membrane.RTP.Header.Extension.html#pop/2"},{"type":"function","title":"Membrane.RTP.Header.Extension.put/2","doc":"","ref":"Membrane.RTP.Header.Extension.html#put/2"},{"type":"type","title":"Membrane.RTP.Header.Extension.identifier_t/0","doc":"","ref":"Membrane.RTP.Header.Extension.html#t:identifier_t/0"},{"type":"type","title":"Membrane.RTP.Header.Extension.t/0","doc":"","ref":"Membrane.RTP.Header.Extension.html#t:t/0"},{"type":"module","title":"Membrane.RTP.HeaderGenerator","doc":"Given following RTP payloads and their minimal metadata, creates their proper header information,\nincrementing timestamps and sequence numbers for each packet. Header information then is put\ninside buffer's metadata under `:rtp` key.\n\nAccepts the following metadata under `:rtp` key: `:marker`, `:csrcs`, `:extensions`.\nSee `Membrane.RTP.Header` for their meaning and specifications.","ref":"Membrane.RTP.HeaderGenerator.html"},{"type":"module","title":"Element options - Membrane.RTP.HeaderGenerator","doc":"Passed via struct `t:Membrane.RTP.HeaderGenerator.t/0`\n\n- `ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n- `payload_type`  \n\n  ```\n  RTP.payload_type_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `clock_rate`  \n\n  ```\n  RTP.clock_rate_t()\n  ```\n  \n  ***Required***","ref":"Membrane.RTP.HeaderGenerator.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.HeaderGenerator","doc":"### `:input`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.HeaderGenerator.html#module-pads"},{"type":"function","title":"Membrane.RTP.HeaderGenerator.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.HeaderGenerator.html#options/0"},{"type":"type","title":"Membrane.RTP.HeaderGenerator.t/0","doc":"Struct containing options for `Membrane.RTP.HeaderGenerator`","ref":"Membrane.RTP.HeaderGenerator.html#t:t/0"},{"type":"module","title":"Membrane.RTP.InboundPacketTracker","doc":"Module responsible for tracking statistics of incoming RTP packets for a single stream.\n\nTracker is capable of repairing packets' sequence numbers provided that it has information about how many packets has\nbeen previously discarded. To updated number of discarded packets one should send an event `Membrane.RTP.PacketsDiscarded.t/0` that will accumulate\nthe total number of discarded packets and will subtract that number from the packet's sequence number.","ref":"Membrane.RTP.InboundPacketTracker.html"},{"type":"module","title":"Element options - Membrane.RTP.InboundPacketTracker","doc":"Passed via struct `t:Membrane.RTP.InboundPacketTracker.t/0`\n\n- `clock_rate`  \n\n  ```\n  Membrane.RTP.clock_rate_t()\n  ```\n  \n  ***Required***  \n  \n\n\n- `repair_sequence_numbers?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `true`  \n  Defines if tracker should try to repair packet's sequence number","ref":"Membrane.RTP.InboundPacketTracker.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.InboundPacketTracker","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.InboundPacketTracker.html#module-pads"},{"type":"function","title":"Membrane.RTP.InboundPacketTracker.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.InboundPacketTracker.html#options/0"},{"type":"type","title":"Membrane.RTP.InboundPacketTracker.t/0","doc":"Struct containing options for `Membrane.RTP.InboundPacketTracker`","ref":"Membrane.RTP.InboundPacketTracker.html#t:t/0"},{"type":"module","title":"Membrane.RTP.JitterBuffer","doc":"Element that buffers and reorders RTP packets based on `sequence_number`.","ref":"Membrane.RTP.JitterBuffer.html"},{"type":"module","title":"Element options - Membrane.RTP.JitterBuffer","doc":"Passed via struct `t:Membrane.RTP.JitterBuffer.t/0`\n\n- `clock_rate`  \n\n  ```\n  RTP.clock_rate_t()\n  ```\n  \n  ***Required***  \n  \n\n\n- `latency`  \n\n  ```\n  Time.t()\n  ```\n  \n  Default value: `200 |> Membrane.Time.milliseconds()`  \n  Delay introduced by JitterBuffer","ref":"Membrane.RTP.JitterBuffer.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.JitterBuffer","doc":"### `:input`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.JitterBuffer.html#module-pads"},{"type":"function","title":"Membrane.RTP.JitterBuffer.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.JitterBuffer.html#options/0"},{"type":"type","title":"Membrane.RTP.JitterBuffer.packet_index/0","doc":"","ref":"Membrane.RTP.JitterBuffer.html#t:packet_index/0"},{"type":"type","title":"Membrane.RTP.JitterBuffer.t/0","doc":"Struct containing options for `Membrane.RTP.JitterBuffer`","ref":"Membrane.RTP.JitterBuffer.html#t:t/0"},{"type":"module","title":"Membrane.RTP.Metrics","doc":"Defines list of metrics, that can be aggregated based on events from membrane_rtp_plugin.","ref":"Membrane.RTP.Metrics.html"},{"type":"function","title":"Membrane.RTP.Metrics.metrics/0","doc":"Returns list of metrics, that can be aggregated based on events from membrane_rtp_plugin.","ref":"Membrane.RTP.Metrics.html#metrics/0"},{"type":"module","title":"Membrane.RTP.OutboundRtxController","doc":"","ref":"Membrane.RTP.OutboundRtxController.html"},{"type":"function","title":"Membrane.RTP.OutboundRtxController.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.OutboundRtxController.html#options/0"},{"type":"type","title":"Membrane.RTP.OutboundRtxController.t/0","doc":"Struct containing options for `Membrane.RTP.OutboundRtxController`","ref":"Membrane.RTP.OutboundRtxController.html#t:t/0"},{"type":"module","title":"Membrane.RTP.OutboundTrackingSerializer","doc":"Tracks statistics of outbound packets.\n\nBesides tracking statistics, tracker can also serialize packet's header and payload stored inside an incoming buffer\ninto a proper RTP packet. When encountering header extensions, it remaps its identifiers from locally used extension\nnames to integer values expected by the receiver.","ref":"Membrane.RTP.OutboundTrackingSerializer.html"},{"type":"module","title":"Element options - Membrane.RTP.OutboundTrackingSerializer","doc":"Passed via struct `t:Membrane.RTP.OutboundTrackingSerializer.t/0`\n\n- `ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n- `payload_type`  \n\n  ```\n  RTP.payload_type_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `clock_rate`  \n\n  ```\n  RTP.clock_rate_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `extension_mapping`  \n\n  ```\n  RTP.SessionBin.rtp_extension_mapping_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `telemetry_label`  \n\n  ```\n  Membrane.TelemetryMetrics.label()\n  ```\n  \n  Default value: `[]`","ref":"Membrane.RTP.OutboundTrackingSerializer.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.OutboundTrackingSerializer","doc":"### `:rtcp_input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:input`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n\n### `:rtcp_output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: RTCP}\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n\n### `:output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: RTP}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.OutboundTrackingSerializer.html#module-pads"},{"type":"function","title":"Membrane.RTP.OutboundTrackingSerializer.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.OutboundTrackingSerializer.html#options/0"},{"type":"type","title":"Membrane.RTP.OutboundTrackingSerializer.t/0","doc":"Struct containing options for `Membrane.RTP.OutboundTrackingSerializer`","ref":"Membrane.RTP.OutboundTrackingSerializer.html#t:t/0"},{"type":"module","title":"Membrane.RTP.Packet","doc":"Defines a struct describing an RTP packet and a way to parse and serialize it.\nBased on [RFC3550](https://tools.ietf.org/html/rfc3550#page-13)\n\nSupports only one-byte header from [RFC8285](https://datatracker.ietf.org/doc/html/rfc8285#section-4.2),\nas according to the document this form is preferred and it must be supported by all receivers.","ref":"Membrane.RTP.Packet.html"},{"type":"function","title":"Membrane.RTP.Packet.identify/1","doc":"","ref":"Membrane.RTP.Packet.html#identify/1"},{"type":"function","title":"Membrane.RTP.Packet.parse/2","doc":"","ref":"Membrane.RTP.Packet.html#parse/2"},{"type":"function","title":"Membrane.RTP.Packet.serialize/2","doc":"","ref":"Membrane.RTP.Packet.html#serialize/2"},{"type":"type","title":"Membrane.RTP.Packet.padding_size/0","doc":"Possible padding size.\n\nIt includes the last byte denoting the size of the padding.","ref":"Membrane.RTP.Packet.html#t:padding_size/0"},{"type":"type","title":"Membrane.RTP.Packet.t/0","doc":"","ref":"Membrane.RTP.Packet.html#t:t/0"},{"type":"module","title":"Membrane.RTP.Packet.PayloadType","doc":"This module contains utility to translate numerical payload type into an atom value.","ref":"Membrane.RTP.Packet.PayloadType.html"},{"type":"function","title":"Membrane.RTP.Packet.PayloadType.get_clock_rate/1","doc":"Gets the clock rate from numerical payload type according to [RFC3551](https://tools.ietf.org/html/rfc3551#page-32).\nFor quick reference check [datasheet](https://www.iana.org/assignments/rtp-parameters/rtp-parameters.xhtml).","ref":"Membrane.RTP.Packet.PayloadType.html#get_clock_rate/1"},{"type":"function","title":"Membrane.RTP.Packet.PayloadType.get_encoding_name/1","doc":"Gets the name of used encoding from numerical payload type according to [RFC3551](https://tools.ietf.org/html/rfc3551#page-32).\nFor quick reference check [datasheet](https://www.iana.org/assignments/rtp-parameters/rtp-parameters.xhtml).","ref":"Membrane.RTP.Packet.PayloadType.html#get_encoding_name/1"},{"type":"function","title":"Membrane.RTP.Packet.PayloadType.is_dynamic/1","doc":"Checks if numerical payload type should be assigned to format type dynamically.","ref":"Membrane.RTP.Packet.PayloadType.html#is_dynamic/1"},{"type":"module","title":"Membrane.RTP.PacketsDiscardedEvent","doc":"Event carrying information about how many packets has been discarded by some element.","ref":"Membrane.RTP.PacketsDiscardedEvent.html"},{"type":"type","title":"Membrane.RTP.PacketsDiscardedEvent.t/0","doc":"","ref":"Membrane.RTP.PacketsDiscardedEvent.html#t:t/0"},{"type":"module","title":"Membrane.RTP.Parser","doc":"Identifies RTP/RTCP packets, then tries to parse RTP packet (parsing header and preparing payload)\nand forwards RTCP packet to `:rtcp_output` pad unchanged.","ref":"Membrane.RTP.Parser.html"},{"type":"module","title":"Encrypted packets - Membrane.RTP.Parser","doc":"In case of SRTP/SRTCP the parser tries to parse just the header of the RTP packet as the packet's payload\nis encrypted and must be passed as a whole to the decryptor. The whole packet remains unchanged but\nthe parsed header gets  attached to `Membrane.Buffer`'s metadata.\n\nSRTP is treated the same as RTCP and all packets gets forwarded to `:rtcp_output` pad.","ref":"Membrane.RTP.Parser.html#module-encrypted-packets"},{"type":"module","title":"Parsed packets - Membrane.RTP.Parser","doc":"In both cases, encrypted and unencryptd, parsed header is put into the metadata field in `Membrane.Buffer` under `:rtp` key.\nwith the following metadata `:timestamp`, `:sequence_number`, `:ssrc`, `:payload_type`,\n`:marker`, `:extension`. See `Membrane.RTP.Header` for their meaning and specifications.","ref":"Membrane.RTP.Parser.html#module-parsed-packets"},{"type":"module","title":"Element options - Membrane.RTP.Parser","doc":"Passed via struct `t:Membrane.RTP.Parser.t/0`\n\n- `secure?`  \n\n  ```\n  any\n  ```\n  \n  Default value: `false`  \n  Specifies whether Parser should expect packets that are encrypted or not.\n  Requires adding [srtp](https://github.com/membraneframework/elixir_libsrtp) dependency to work.","ref":"Membrane.RTP.Parser.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.Parser","doc":"### `:input`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: cf} when cf in [nil, RTP, RTCP]\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:rtcp_output`\n\nAccepted formats:\n```\n%RemoteStream{content_format: RTCP, type: :packetized}\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nFlow control: | `:push`\nDemand unit: | `nil`\n\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.Parser.html#module-pads"},{"type":"function","title":"Membrane.RTP.Parser.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.Parser.html#options/0"},{"type":"type","title":"Membrane.RTP.Parser.t/0","doc":"Struct containing options for `Membrane.RTP.Parser`","ref":"Membrane.RTP.Parser.html#t:t/0"},{"type":"module","title":"Membrane.RTP.PayloadFormatResolver","doc":"Wrapper over `Membrane.RTP.PayloadFormat` that returns payloaders and depayloaders, or an error\nif they can't be resolved.","ref":"Membrane.RTP.PayloadFormatResolver.html"},{"type":"function","title":"Membrane.RTP.PayloadFormatResolver.depayloader/1","doc":"Tries to resolve a depayloader based on given encoding.","ref":"Membrane.RTP.PayloadFormatResolver.html#depayloader/1"},{"type":"function","title":"Membrane.RTP.PayloadFormatResolver.frame_detector/1","doc":"","ref":"Membrane.RTP.PayloadFormatResolver.html#frame_detector/1"},{"type":"function","title":"Membrane.RTP.PayloadFormatResolver.keyframe_detector/1","doc":"","ref":"Membrane.RTP.PayloadFormatResolver.html#keyframe_detector/1"},{"type":"function","title":"Membrane.RTP.PayloadFormatResolver.payloader/1","doc":"Tries to resolve a payloader based on given encoding.","ref":"Membrane.RTP.PayloadFormatResolver.html#payloader/1"},{"type":"type","title":"Membrane.RTP.PayloadFormatResolver.encoding_mapper_t/0","doc":"","ref":"Membrane.RTP.PayloadFormatResolver.html#t:encoding_mapper_t/0"},{"type":"module","title":"Membrane.RTP.PayloaderBin","doc":"Module responsible for payloading a stream to RTP format and preparing RTP headers.","ref":"Membrane.RTP.PayloaderBin.html"},{"type":"module","title":"Bin options - Membrane.RTP.PayloaderBin","doc":"Passed via struct `t:Membrane.RTP.PayloaderBin.t/0`\n\n- `payloader`  \n\n  ```\n  module()\n  ```\n  \n  ***Required***  \n  Payloader module used for payloading a stream to RTP format\n\n\n- `ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `payload_type`  \n\n  ```\n  RTP.payload_type_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `clock_rate`  \n\n  ```\n  RTP.clock_rate_t()\n  ```\n  \n  ***Required***","ref":"Membrane.RTP.PayloaderBin.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.RTP.PayloaderBin","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:always`","ref":"Membrane.RTP.PayloaderBin.html#module-pads"},{"type":"function","title":"Membrane.RTP.PayloaderBin.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.PayloaderBin.html#options/0"},{"type":"type","title":"Membrane.RTP.PayloaderBin.t/0","doc":"Struct containing options for `Membrane.RTP.PayloaderBin`","ref":"Membrane.RTP.PayloaderBin.html#t:t/0"},{"type":"module","title":"Membrane.RTP.RTXParser","doc":"An element responsible for handling retransmission packets (`rtx`) defined in\n[RFC 4588](https://datatracker.ietf.org/doc/html/rfc4588#section-4).\n\nIt parses RTX packet and recreates the lost packet by stripping rtx header from buffer's payload\nand updating rtp metadata. The changed fields are:\n  * `sequence_number` - set to value transported in rtx header\n  * `payload_type` - set via `original_payload_type` option\n  * if `rid_id` and `repaired_rid_id` are provided, the former replaces the latter in a matching `:extensions` entry","ref":"Membrane.RTP.RTXParser.html"},{"type":"module","title":"Element options - Membrane.RTP.RTXParser","doc":"Passed via struct `t:Membrane.RTP.RTXParser.t/0`\n\n- `original_payload_type`  \n\n  ```\n  any\n  ```\n  \n  ***Required***  \n  Payload type of original RTP stream that is retransmitted via the parsed RTX stream\n\n\n- `repaired_rid_id`  \n\n  ```\n  RTP.Header.Extension.identifier_t()\n  ```\n  \n  Default value: `nil`  \n  The numerical ID of an extension carrying repaired-rid that will be rewritten into rid\n\n\n\n- `rid_id`  \n\n  ```\n  RTP.Header.Extension.identifier_t()\n  ```\n  \n  Default value: `nil`  \n  The numerical ID of an extension carrying rid, will replace repaired_rid_id","ref":"Membrane.RTP.RTXParser.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.RTXParser","doc":"### `:input`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.RTXParser.html#module-pads"},{"type":"function","title":"Membrane.RTP.RTXParser.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.RTXParser.html#options/0"},{"type":"type","title":"Membrane.RTP.RTXParser.t/0","doc":"Struct containing options for `Membrane.RTP.RTXParser`","ref":"Membrane.RTP.RTXParser.html#t:t/0"},{"type":"module","title":"Membrane.RTP.RetransmissionRequestEvent","doc":"An event used to request a retransmission of packet(s).\n\nIn the element responsible for sending NACKs it will be turned into\n`Membrane.RTCP.TransportFeedbackPacket.NACK` and sent to the RTP sender","ref":"Membrane.RTP.RetransmissionRequestEvent.html"},{"type":"module","title":"Membrane.RTP.SSRCRouter","doc":"A filter separating RTP packets from different SSRCs into different outpts.\n\nWhen receiving a new SSRC, it creates a new pad and notifies its parent (`t:new_stream_notification_t/0`) that should link\nthe new output pad.\n\nWhen an RTCP event arrives from some output pad the router tries to forward it to a proper input pad.\nThe input pad gets chosen by the source input pad from which packets with given ssrc were previously sent,\nthe source pad's id gets extracted and the router tries to send the event to an input\npad of id `{:input, id}`, if no such pad exists the router simply drops the event.","ref":"Membrane.RTP.SSRCRouter.html"},{"type":"module","title":"Pads - Membrane.RTP.SSRCRouter","doc":"### `:input`\n\nAccepted formats:\n```\nRTCP\n```\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`\nPad options:\n\n- `telemetry_label`  \n\n  ```\n  Membrane.TelemetryMetrics.label()\n  ```\n  \n  Default value: `[]`  \n  \n\n\n- `encoding`  \n\n  ```\n  atom() | nil\n  ```\n  \n  Default value: `nil`","ref":"Membrane.RTP.SSRCRouter.html#module-pads"},{"type":"type","title":"Membrane.RTP.SSRCRouter.new_stream_notification_t/0","doc":"Notification sent when an RTP packet with new SSRC arrives and new output pad should be linked","ref":"Membrane.RTP.SSRCRouter.html#t:new_stream_notification_t/0"},{"type":"type","title":"Membrane.RTP.SSRCRouter.output_pad_opts/0","doc":"Options for pad `:output`","ref":"Membrane.RTP.SSRCRouter.html#t:output_pad_opts/0"},{"type":"module","title":"Membrane.RTP.SSRCRouter.StreamsInfo","doc":"A struct sent as a message to `Membrane.RTP.SSRCRouter` with info about known streams\nand streams that will be identified by extensions and should not be reported until they are present\n\nIn particular, simulcast tracks need a RID extension in header in order to be handled.","ref":"Membrane.RTP.SSRCRouter.StreamsInfo.html"},{"type":"type","title":"Membrane.RTP.SSRCRouter.StreamsInfo.t/0","doc":"","ref":"Membrane.RTP.SSRCRouter.StreamsInfo.html#t:t/0"},{"type":"module","title":"Membrane.RTP.SequenceNumberTracker","doc":"A module used to map 16-bit sequence number to a continuous index without rollovers.\nIt also detectes repeated and lost packets","ref":"Membrane.RTP.SequenceNumberTracker.html"},{"type":"function","title":"Membrane.RTP.SequenceNumberTracker.new/0","doc":"Initializes new SequenceNumberTracker","ref":"Membrane.RTP.SequenceNumberTracker.html#new/0"},{"type":"function","title":"Membrane.RTP.SequenceNumberTracker.track/2","doc":"Main function of the Tracker that returns a difference to the newest package and packet's monotonic index","ref":"Membrane.RTP.SequenceNumberTracker.html#track/2"},{"type":"type","title":"Membrane.RTP.SequenceNumberTracker.t/0","doc":"","ref":"Membrane.RTP.SequenceNumberTracker.html#t:t/0"},{"type":"module","title":"Membrane.RTP.Serializer.Stats","doc":"Serializer stats that can be used for Sender Report(SR) generation","ref":"Membrane.RTP.Serializer.Stats.html"},{"type":"type","title":"Membrane.RTP.Serializer.Stats.t/0","doc":"","ref":"Membrane.RTP.Serializer.Stats.html#t:t/0"},{"type":"module","title":"Membrane.RTP.SilenceDiscarder","doc":"Element responsible for dropping silent audio packets.\n\nFor a packet to be discarded it needs to contain a `RTP.Header.Extension` struct with identifier equal to `vad_id` in\nits extensions list. The header extension will contain information about audio level (VAD extension is required).\nThe element will only drop packets whose audio level is above given silence threshold (muted audio is of value 127).\n\n`Elixir.Membrane.RTP.SilenceDiscarder` will drop as many silent packets as possible and on reaching dropping limit it will send the current buffer,\nreset dropped packets counter and emit `Membrane.RTP.DroppedPacketEvent` with a number of packets that have been dropped until that point.\nThe event gets sent on both reaching dropping limit and when a non-silent packet arrives.","ref":"Membrane.RTP.SilenceDiscarder.html"},{"type":"module","title":"Element options - Membrane.RTP.SilenceDiscarder","doc":"Passed via struct `t:Membrane.RTP.SilenceDiscarder.t/0`\n\n- `max_consecutive_drops`  \n\n  ```\n  non_neg_integer() | :infinity\n  ```\n  \n  Default value: `1000`  \n  A number indicating how many consecutive silent packets can be dropped before\n  a single packet will be passed and dropped packet event will we emitted.\n  \n  Passing a single packets once in a while is necessary for element such as jitter buffer or encryptor as they can update their ROCs\n  based on sequence numbers and when we drop to many packets we may roll it over.\n\n\n- `silence_threshold`  \n\n  ```\n  1..127\n  ```\n  \n  Default value: `127`  \n  Audio level threshold that will be compared against incoming packets. Packet will be dropped if its audio level\n  is above or equal to the given threshold.\n\n\n\n- `vad_id`  \n\n  ```\n  1..14\n  ```\n  \n  Default value: `1`  \n  ID of a VAD extension.","ref":"Membrane.RTP.SilenceDiscarder.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.SilenceDiscarder","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.SilenceDiscarder.html#module-pads"},{"type":"function","title":"Membrane.RTP.SilenceDiscarder.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.SilenceDiscarder.html#options/0"},{"type":"type","title":"Membrane.RTP.SilenceDiscarder.t/0","doc":"Struct containing options for `Membrane.RTP.SilenceDiscarder`","ref":"Membrane.RTP.SilenceDiscarder.html#t:t/0"},{"type":"module","title":"Membrane.RTP.StreamReceiveBin","doc":"This bin gets a parsed RTP stream on input and outputs raw media stream.\n\nIts responsibility is to depayload the RTP stream and compensate the\njitter.","ref":"Membrane.RTP.StreamReceiveBin.html"},{"type":"module","title":"Bin options - Membrane.RTP.StreamReceiveBin","doc":"Passed via struct `t:Membrane.RTP.StreamReceiveBin.t/0`\n\n- `srtp_policies`  \n\n  ```\n  [ExLibSRTP.Policy.t()]\n  ```\n  \n  Default value: `[]`  \n  \n\n\n- `secure?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  \n\n\n\n- `extensions`  \n\n  ```\n  [RTP.SessionBin.extension_t()]\n  ```\n  \n  Default value: `[]`  \n  \n\n\n\n- `clock_rate`  \n\n  ```\n  RTP.clock_rate_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `depayloader`  \n\n  ```\n  module() | nil\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `local_ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `remote_ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `rtcp_report_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `telemetry_label`  \n\n  ```\n  [{atom(), any()}]\n  ```\n  \n  Default value: `[]`","ref":"Membrane.RTP.StreamReceiveBin.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.RTP.StreamReceiveBin","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`","ref":"Membrane.RTP.StreamReceiveBin.html#module-pads"},{"type":"function","title":"Membrane.RTP.StreamReceiveBin.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.StreamReceiveBin.html#options/0"},{"type":"type","title":"Membrane.RTP.StreamReceiveBin.t/0","doc":"Struct containing options for `Membrane.RTP.StreamReceiveBin`","ref":"Membrane.RTP.StreamReceiveBin.html#t:t/0"},{"type":"module","title":"Membrane.RTP.StreamSendBin","doc":"Bin payloading and serializing media stream to RTP.","ref":"Membrane.RTP.StreamSendBin.html"},{"type":"module","title":"Bin options - Membrane.RTP.StreamSendBin","doc":"Passed via struct `t:Membrane.RTP.StreamSendBin.t/0`\n\n- `payloader`  \n\n  ```\n  module\n  ```\n  \n  Default value: `nil`  \n  \n\n\n- `payload_type`  \n\n  ```\n  RTP.payload_type_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `clock_rate`  \n\n  ```\n  RTP.clock_rate_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `rtcp_report_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `rtp_extension_mapping`  \n\n  ```\n  RTP.SessionBin.rtp_extension_mapping_t()\n  ```\n  \n  Default value: `nil`  \n  \n\n\n\n- `telemetry_label`  \n\n  ```\n  Membrane.TelemetryMetrics.label()\n  ```\n  \n  Default value: `[]`","ref":"Membrane.RTP.StreamSendBin.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.RTP.StreamSendBin","doc":"### `:rtcp_input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\n\n\n### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\n\n\n\n### `:rtcp_output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\n\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`","ref":"Membrane.RTP.StreamSendBin.html#module-pads"},{"type":"function","title":"Membrane.RTP.StreamSendBin.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.StreamSendBin.html#options/0"},{"type":"type","title":"Membrane.RTP.StreamSendBin.t/0","doc":"Struct containing options for `Membrane.RTP.StreamSendBin`","ref":"Membrane.RTP.StreamSendBin.html#t:t/0"},{"type":"module","title":"Membrane.RTP.TWCCReceiver","doc":"The module defines an element responsible for recording transport-wide statistics of incoming packets\nand generating TWCC feedbacks.","ref":"Membrane.RTP.TWCCReceiver.html"},{"type":"module","title":"Element options - Membrane.RTP.TWCCReceiver","doc":"Passed via struct `t:Membrane.RTP.TWCCReceiver.t/0`\n\n- `twcc_id`  \n\n  ```\n  1..14\n  ```\n  \n  ***Required***  \n  ID of TWCC header extension.\n\n\n- `report_interval`  \n\n  ```\n  Membrane.Time.t()\n  ```\n  \n  Default value: `250000000`  \n  How often to generate feedback packets.\n\n\n\n- `feedback_sender_ssrc`  \n\n  ```\n  RTP.ssrc_t() | nil\n  ```\n  \n  Default value: `nil`  \n  Sender SSRC for generated feedback packets (will be supplied by `RTP.SessionBin`).","ref":"Membrane.RTP.TWCCReceiver.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.TWCCReceiver","doc":"### `:input`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.TWCCReceiver.html#module-pads"},{"type":"function","title":"Membrane.RTP.TWCCReceiver.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.TWCCReceiver.html#options/0"},{"type":"type","title":"Membrane.RTP.TWCCReceiver.t/0","doc":"Struct containing options for `Membrane.RTP.TWCCReceiver`","ref":"Membrane.RTP.TWCCReceiver.html#t:t/0"},{"type":"module","title":"Membrane.RTP.TWCCSender","doc":"The module defines an element responsible for tagging outgoing packets with transport-wide sequence numbers and\nestimating available bandwidth.","ref":"Membrane.RTP.TWCCSender.html"},{"type":"module","title":"Pads - Membrane.RTP.TWCCSender","doc":"### `:input`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\nRTP\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.TWCCSender.html#module-pads"},{"type":"module","title":"Membrane.RTP.VAD","doc":"Vad based on audio level sent in RTP header.\n\nTo make this module work appropriate RTP header extension has to be set in the SDP offer/answer.\n\nSends `Membrane.RTP.VadEvent` when a score from `Membrane.RTP.Vad.IsSpeakingEstimator` changes.\n\nA more detailed explanation of how the VAD algorithm can be found in the `Membrane.RTP.Vad.IsSpeakingEstimator` module.\n\nBuffers that are processed by this element may or may not have been processed by\na depayloader and passed through a jitter buffer. If they have not, then the only timestamp\navailable for time comparison is the RTP timestamp.\n\nWhen calculating the epoch of the timestamp, we need to account for 32bit integer wrapping.\n* `:current` - the difference between timestamps is low: the timestamp has not wrapped around.\n* `:next` - the timestamp has wrapped around to 0. To simplify queue processing we reset the state.\n* `:prev` - the timestamp has recently wrapped around. We might receive an out-of-order packet\n  from before the rollover, which we ignore.","ref":"Membrane.RTP.VAD.html"},{"type":"module","title":"Element options - Membrane.RTP.VAD","doc":"Passed via struct `t:Membrane.RTP.VAD.t/0`\n\n- `vad_id`  \n\n  ```\n  1..14\n  ```\n  \n  ***Required***  \n  ID of VAD header extension.\n\n\n- `vad_threshold`  \n\n  ```\n  -127..0\n  ```\n  \n  Default value: `-32`  \n  Audio level in dBov representing vad threshold.\n  Values above are considered to represent voice activity.\n  Value -127 represents digital silence.","ref":"Membrane.RTP.VAD.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTP.VAD","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTP.VAD.html#module-pads"},{"type":"function","title":"Membrane.RTP.VAD.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTP.VAD.html#options/0"},{"type":"type","title":"Membrane.RTP.VAD.t/0","doc":"Struct containing options for `Membrane.RTP.VAD`","ref":"Membrane.RTP.VAD.html#t:t/0"},{"type":"module","title":"Membrane.RTP.Vad.IsSpeakingEstimator","doc":"Module for estimating if the user is speaking inspired by\n[*Dominant Speaker Identification for Multipoint Videoconferencing*](https://israelcohen.com/wp-content/uploads/2018/05/IEEEI2012_Volfin.pdf)\nby Ilana Volfin and Israel Cohen\n\n------\n\nThe `estimate_is_speaking/2` function takes a list of audio levels in range [0, 127]\nand based on a threshold given as a second input\ncomputes if the person is speaking.\n\nThe input levels are interpreted on 3 tiers. Each tier consists of intervals specified below:\n\n| Name         | Interpretation       | Number of RTP packets (default) | length    |\n|--------------|----------------------|---------------------------------|-----------|\n| `immediate`  | smallest sound chunk | 1                               | ~20 [ms]  |\n| `medium`     | one word             | 1 * 10 = 10                    | ~200 [ms] |\n| `long`       | half/one sentence    | 1 \\* 10 * 7 = 70              | ~1.4 [s]  |\n\nEach tier interval is computed based on the smaller tier intervals (subunits).\nImmediates are computed based on levels, mediums on top of immediates and longs on top of mediums.\nThe number of subunits in one interval is given as a module parameter.\n\nEach interval is a number of active subunits (that is: lower tier intervals) above a threshold of a given tier.\n\n> **Example**\n>\n> If `level_threshold` is `90`, levels are `[80, 90, 100, 90]` and there are 2 levels in a immediate\n> then `immediates` would be equal to `[1, 2]` since subunit of `[80, 90]` has 1 item above or equal to\n> the threshold and subunit `[100, 90]` has 2 such items.\n>\n> Same goes for mediums. If `medium subunit threshold` is 2 and number of subunits is 2\n> then `mediums` are equal to `[1]` since the only subunit `[1, 2]` had only one element above or equal to the threshold.\n\nThe number of levels the function requires equals the product of the subunits number required for each tier.\nThis way we compute only one long interval because only one is needed.\nIf the number of levels is smaller than the required minimum, the algorithm returns silence.\n\nThe most recent interval in each tier serves as a basis for computing an activity score.\nThe activity score is a logarithm of a quotient of:\n  - the probability of `k` active items in `n` total items under an assumption that a person is speaking (modeled as a *binomial distribution*)\n  - probability same as above but under an assumption that a person is not speaking (modeled as an *exponential distribution*)\n\nThe activity score for each tier is then thresholded again.\nA threshold for every tier is given as a module parameter.\nIf all activity scores are over the threshold, the algorithm returns that the input contains speech.\nOtherwise the algorithm returns that input contains silence.\n\n-----------------\nOverall the parameters for each tier are:\n\n| Parameter | Description |\n|-|-|\n| `subunits` | number of smaller units in one bigger unit |\n| `score_threshold`  | number equal or above which the activity score of the given tier must be to be counted as indicating speech |\n| `subunit_threshold` | number equal or above which the number of active subunits must be for the given tier to be marked as active (for `immediates` it is equal to the threshold given as a `estimate_is_speaking/2` argument) |\n| `lambda` | parameter for the exponential distribution (element of the activity score computations) |\n\nYou can set them, by adding the following code to your `config.exs`\n\n```\nconfig :membrane_rtp_plugin,\n  vad_estimation_parameters: %{\n    immediate: %{\n      subunits: 1,\n      score_threshold: 0,\n      lambda: 1\n    },\n    medium: %{\n      subunits: 10,\n      score_threshold: 20,\n      subunit_threshold: 1,\n      lambda: 24\n    },\n    long: %{\n      subunits: 7,\n      score_threshold: 20,\n      subunit_threshold: 3,\n      lambda: 47\n    }\n  }\n```\n\nA thorough explanation with images can be found in the Jellyfish book in the [Voice Activity Detection](https://jellyfish-dev.github.io/book/webrtc/voice_activity_detection/vad.html) chapter.","ref":"Membrane.RTP.Vad.IsSpeakingEstimator.html"},{"type":"function","title":"Membrane.RTP.Vad.IsSpeakingEstimator.estimate_is_speaking/2","doc":"Estimates if the user is speaking based on the audio levels and a threshold.","ref":"Membrane.RTP.Vad.IsSpeakingEstimator.html#estimate_is_speaking/2"},{"type":"module","title":"Membrane.RTP.VadEvent","doc":"An event informing about Voice Activity Detection status changes","ref":"Membrane.RTP.VadEvent.html"},{"type":"type","title":"Membrane.RTP.VadEvent.t/0","doc":"Type describing the structure of the Voice Activity Detection event.\n\n- `:vad` - contains information about VAD status. Indicates either speech or silence.\n  For details on voice activity detection algorithm, refer to `Membrane.RTP.VAD`","ref":"Membrane.RTP.VadEvent.html#t:t/0"},{"type":"module","title":"Membrane.RTCPEvent","doc":"Event carrying a parsed RTCP packet.","ref":"Membrane.RTCPEvent.html"},{"type":"type","title":"Membrane.RTCPEvent.t/0","doc":"","ref":"Membrane.RTCPEvent.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.AppPacket","doc":"Parses RTCP Application-defined (APP) packets\ndefined in [RFC3550](https://tools.ietf.org/html/rfc3550#section-6.7)","ref":"Membrane.RTCP.AppPacket.html"},{"type":"type","title":"Membrane.RTCP.AppPacket.t/0","doc":"","ref":"Membrane.RTCP.AppPacket.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.ByePacket","doc":"Parses and constructs RTCP BYE packets defined in\n[RFC3550](https://tools.ietf.org/html/rfc3550#section-6.6)","ref":"Membrane.RTCP.ByePacket.html"},{"type":"type","title":"Membrane.RTCP.ByePacket.t/0","doc":"","ref":"Membrane.RTCP.ByePacket.html#t:t/0"},{"type":"behaviour","title":"Membrane.RTCP.FeedbackPacket","doc":"Abstraction and generic encoding/decoding functionality for\n[RTCP payload-specific feedback packets](https://datatracker.ietf.org/doc/html/rfc5104#section-4.3).","ref":"Membrane.RTCP.FeedbackPacket.html"},{"type":"callback","title":"Membrane.RTCP.FeedbackPacket.decode/1","doc":"","ref":"Membrane.RTCP.FeedbackPacket.html#c:decode/1"},{"type":"callback","title":"Membrane.RTCP.FeedbackPacket.encode/1","doc":"","ref":"Membrane.RTCP.FeedbackPacket.html#c:encode/1"},{"type":"type","title":"Membrane.RTCP.FeedbackPacket.t/0","doc":"","ref":"Membrane.RTCP.FeedbackPacket.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.FeedbackPacket.AFB","doc":"[Application Layer Feedback](https://datatracker.ietf.org/doc/html/rfc4585#section-6.4) packets.\n\nThey use PT=PSFB (206) & FMT=15.\nSince the message must be handled at the application layer, the struct simply wraps a binary content of message","ref":"Membrane.RTCP.FeedbackPacket.AFB.html"},{"type":"module","title":"Membrane.RTCP.FeedbackPacket.FIR","doc":"Encodes and decodes [Full Intra Request](https://datatracker.ietf.org/doc/html/rfc5104#section-4.3.1) packets.","ref":"Membrane.RTCP.FeedbackPacket.FIR.html"},{"type":"module","title":"Membrane.RTCP.FeedbackPacket.PLI","doc":"Encodes and decodes [Picture Loss Indication](https://datatracker.ietf.org/doc/html/rfc4585#section-6.3.1) packets.","ref":"Membrane.RTCP.FeedbackPacket.PLI.html"},{"type":"module","title":"Membrane.RTCP.Header","doc":"Struct describing 32-bit header common to all RTCP packets","ref":"Membrane.RTCP.Header.html"},{"type":"function","title":"Membrane.RTCP.Header.parse/1","doc":"","ref":"Membrane.RTCP.Header.html#parse/1"},{"type":"function","title":"Membrane.RTCP.Header.serialize/2","doc":"","ref":"Membrane.RTCP.Header.html#serialize/2"},{"type":"type","title":"Membrane.RTCP.Header.packet_specific_t/0","doc":"","ref":"Membrane.RTCP.Header.html#t:packet_specific_t/0"},{"type":"type","title":"Membrane.RTCP.Header.packet_type_t/0","doc":"","ref":"Membrane.RTCP.Header.html#t:packet_type_t/0"},{"type":"type","title":"Membrane.RTCP.Header.t/0","doc":"","ref":"Membrane.RTCP.Header.html#t:t/0"},{"type":"behaviour","title":"Membrane.RTCP.Packet","doc":"Functions common to all RTCP Packets","ref":"Membrane.RTCP.Packet.html"},{"type":"callback","title":"Membrane.RTCP.Packet.decode/2","doc":"Decodes binary with packet body (without header) into packet struct. Used by `parse/1`","ref":"Membrane.RTCP.Packet.html#c:decode/2"},{"type":"callback","title":"Membrane.RTCP.Packet.encode/1","doc":"Encodes packet struct into the tuple used by `serialize/1`","ref":"Membrane.RTCP.Packet.html#c:encode/1"},{"type":"function","title":"Membrane.RTCP.Packet.parse/1","doc":"","ref":"Membrane.RTCP.Packet.html#parse/1"},{"type":"function","title":"Membrane.RTCP.Packet.serialize/1","doc":"Converts packet structure into binary","ref":"Membrane.RTCP.Packet.html#serialize/1"},{"type":"type","title":"Membrane.RTCP.Packet.t/0","doc":"","ref":"Membrane.RTCP.Packet.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.Parser","doc":"Element responsible for receiving raw RTCP packets, parsing them and emitting proper RTCP events.","ref":"Membrane.RTCP.Parser.html"},{"type":"module","title":"Pads - Membrane.RTCP.Parser","doc":"### `:input`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: cf} when cf in [nil, RTCP]\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:receiver_report_output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: RTCP}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:push`\nDemand unit: | `nil`\n\n\n\n### `:output`\n\nAccepted formats:\n```\nRTCP\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTCP.Parser.html#module-pads"},{"type":"module","title":"Membrane.RTCP.Receiver","doc":"Element exchanging RTCP packets and RTCP receiver statistics.","ref":"Membrane.RTCP.Receiver.html"},{"type":"module","title":"Element options - Membrane.RTCP.Receiver","doc":"Passed via struct `t:Membrane.RTCP.Receiver.t/0`\n\n- `local_ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n- `remote_ssrc`  \n\n  ```\n  RTP.ssrc_t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `report_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  \n\n\n\n- `telemetry_label`  \n\n  ```\n  Membrane.TelemetryMetrics.label()\n  ```\n  \n  Default value: `[]`","ref":"Membrane.RTCP.Receiver.html#module-element-options"},{"type":"module","title":"Pads - Membrane.RTCP.Receiver","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.RTCP.Receiver.html#module-pads"},{"type":"function","title":"Membrane.RTCP.Receiver.options/0","doc":"Returns description of options available for this module","ref":"Membrane.RTCP.Receiver.html#options/0"},{"type":"type","title":"Membrane.RTCP.Receiver.t/0","doc":"Struct containing options for `Membrane.RTCP.Receiver`","ref":"Membrane.RTCP.Receiver.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.ReceiverReport.Stats","doc":"JitterBuffer stats that can be used for Receiver report generation","ref":"Membrane.RTCP.ReceiverReport.Stats.html"},{"type":"type","title":"Membrane.RTCP.ReceiverReport.Stats.t/0","doc":"","ref":"Membrane.RTCP.ReceiverReport.Stats.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.ReceiverReport.StatsEvent","doc":"Event carrying statistics for a receiver report.","ref":"Membrane.RTCP.ReceiverReport.StatsEvent.html"},{"type":"type","title":"Membrane.RTCP.ReceiverReport.StatsEvent.t/0","doc":"","ref":"Membrane.RTCP.ReceiverReport.StatsEvent.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.ReceiverReport.StatsRequestEvent","doc":"Event to be sent to jitter buffer to request statistics.","ref":"Membrane.RTCP.ReceiverReport.StatsRequestEvent.html"},{"type":"type","title":"Membrane.RTCP.ReceiverReport.StatsRequestEvent.t/0","doc":"","ref":"Membrane.RTCP.ReceiverReport.StatsRequestEvent.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.ReceiverReportPacket","doc":"Parses and constructs RTCP Receiver Report defined in\n[RFC3550](https://tools.ietf.org/html/rfc3550#section-6.4.2)","ref":"Membrane.RTCP.ReceiverReportPacket.html"},{"type":"type","title":"Membrane.RTCP.ReceiverReportPacket.t/0","doc":"","ref":"Membrane.RTCP.ReceiverReportPacket.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.ReportPacketBlock","doc":"Parses and constructs report blocks, which are parts of RTCP Sender and Receiver Reports\ndefined in [RFC3550](https://tools.ietf.org/html/rfc3550#section-6.4)","ref":"Membrane.RTCP.ReportPacketBlock.html"},{"type":"function","title":"Membrane.RTCP.ReportPacketBlock.decode/1","doc":"","ref":"Membrane.RTCP.ReportPacketBlock.html#decode/1"},{"type":"function","title":"Membrane.RTCP.ReportPacketBlock.encode/1","doc":"","ref":"Membrane.RTCP.ReportPacketBlock.html#encode/1"},{"type":"type","title":"Membrane.RTCP.ReportPacketBlock.t/0","doc":"","ref":"Membrane.RTCP.ReportPacketBlock.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.SdesPacket","doc":"Parses Source Description (SDES) RTCP Packets defined in\n[RFC3550](https://tools.ietf.org/html/rfc3550#section-6.5)","ref":"Membrane.RTCP.SdesPacket.html"},{"type":"type","title":"Membrane.RTCP.SdesPacket.t/0","doc":"","ref":"Membrane.RTCP.SdesPacket.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.SenderReportPacket","doc":"Parses and constructs RTCP Sender Report defined in\n[RFC3550](https://tools.ietf.org/html/rfc3550#section-6.4.1)","ref":"Membrane.RTCP.SenderReportPacket.html"},{"type":"type","title":"Membrane.RTCP.SenderReportPacket.sender_info_t/0","doc":"","ref":"Membrane.RTCP.SenderReportPacket.html#t:sender_info_t/0"},{"type":"type","title":"Membrane.RTCP.SenderReportPacket.t/0","doc":"","ref":"Membrane.RTCP.SenderReportPacket.html#t:t/0"},{"type":"behaviour","title":"Membrane.RTCP.TransportFeedbackPacket","doc":"Abstraction and generic encoding/decoding functionality for\n[RTCP transport layer feedback packets](https://datatracker.ietf.org/doc/html/rfc4585#section-6.1).","ref":"Membrane.RTCP.TransportFeedbackPacket.html"},{"type":"callback","title":"Membrane.RTCP.TransportFeedbackPacket.decode/1","doc":"","ref":"Membrane.RTCP.TransportFeedbackPacket.html#c:decode/1"},{"type":"callback","title":"Membrane.RTCP.TransportFeedbackPacket.encode/1","doc":"","ref":"Membrane.RTCP.TransportFeedbackPacket.html#c:encode/1"},{"type":"type","title":"Membrane.RTCP.TransportFeedbackPacket.t/0","doc":"","ref":"Membrane.RTCP.TransportFeedbackPacket.html#t:t/0"},{"type":"module","title":"Membrane.RTCP.TransportFeedbackPacket.NACK","doc":"Generic Negative Acknowledgment packet that informs about lost RTP packet(s)\n\nQuoting [RFC4585](https://datatracker.ietf.org/doc/html/rfc4585#section-6.2.1):\nThe Generic NACK is used to indicate the loss of one or more RTP packets.\nThe lost packet(s) are identified by the means of a packet identifier and a bit mask.\n\nThe Feedback Control Information (FCI) field has the following Syntax (Figure 4):\n\n```txt\n  0                   1                   2                   3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n |            PID                |             BLP               |\n +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n             Figure 4: Syntax for the Generic NACK message\n\nPacket ID (PID): 16 bits\n   The PID field is used to specify a lost packet.  The PID field\n   refers to the RTP sequence number of the lost packet.\n\n\nbitmask of following lost packets (BLP): 16 bits\n   The BLP allows for reporting losses of any of the 16 RTP packets\n   immediately following the RTP packet indicated by the PID.  The\n   BLP's definition is identical to that given in [6].  Denoting the\n   BLP's least significant bit as bit 1, and its most significant bit\n   as bit 16, then bit i of the bit mask is set to 1 if the receiver\n   has not received RTP packet number (PID+i) (modulo 2^16) and\n   indicates this packet is lost; bit i is set to 0 otherwise.  Note\n   that the sender MUST NOT assume that a receiver has received a\n   packet because its bit mask was set to 0.  For example, the least\n   significant bit of the BLP would be set to 1 if the packet\n   corresponding to the PID and the following packet have been lost.\n   However, the sender cannot infer that packets PID+2 through PID+16\n   have been received simply because bits 2 through 15 of the BLP are\n   0; all the sender knows is that the receiver has not reported them\n   as lost at this time.\n\n```\nImplementation based on https://datatracker.ietf.org/doc/html/rfc4585#section-6.2.1\nand https://datatracker.ietf.org/doc/html/rfc2032#section-5.2.2","ref":"Membrane.RTCP.TransportFeedbackPacket.NACK.html"},{"type":"module","title":"Membrane.RTCP.TransportFeedbackPacket.TWCC","doc":"Encodes and decodes [Transport-wide congestion control](https://datatracker.ietf.org/doc/html/draft-holmer-rmcat-transport-wide-cc-extensions-01)\nfeedback packets.","ref":"Membrane.RTCP.TransportFeedbackPacket.TWCC.html"},{"type":"type","title":"Membrane.RTCP.TransportFeedbackPacket.TWCC.t/0","doc":"","ref":"Membrane.RTCP.TransportFeedbackPacket.TWCC.html#t:t/0"},{"type":"module","title":"Membrane.SRTP.Decryptor","doc":"Converts SRTP packets to plain RTP.\n\nDecryptor expects that buffers passed to `handle_process/4` have already parsed headers\nin the metadata field as they contain information about header length. The header\nlength is needed to avoid parsing the header twice in case of any elements preceding\nthe decryptor needed the information to e.g. drop the packet before reaching the decryptor.\n`ExLibSRTP` expects a valid SRTP packet containing the header, after decryption, the\npayload binary again includes the header. The header's length simply allows stripping\nthe header without any additional parsing.\n\nRequires adding [srtp](https://github.com/membraneframework/elixir_libsrtp) dependency to work.","ref":"Membrane.SRTP.Decryptor.html"},{"type":"module","title":"Element options - Membrane.SRTP.Decryptor","doc":"Passed via struct `t:Membrane.SRTP.Decryptor.t/0`\n\n- `policies`  \n\n  ```\n  [ExLibSRTP.Policy.t()]\n  ```\n  \n  ***Required***  \n  List of SRTP policies to use for decrypting packets.\n  See `t:ExLibSRTP.Policy.t/0` for details.","ref":"Membrane.SRTP.Decryptor.html#module-element-options"},{"type":"module","title":"Pads - Membrane.SRTP.Decryptor","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.SRTP.Decryptor.html#module-pads"},{"type":"function","title":"Membrane.SRTP.Decryptor.options/0","doc":"Returns description of options available for this module","ref":"Membrane.SRTP.Decryptor.html#options/0"},{"type":"type","title":"Membrane.SRTP.Decryptor.t/0","doc":"Struct containing options for `Membrane.SRTP.Decryptor`","ref":"Membrane.SRTP.Decryptor.html#t:t/0"},{"type":"module","title":"Membrane.SRTP.Encryptor","doc":"Converts plain RTP packets to SRTP.\n\nRequires adding [srtp](https://github.com/membraneframework/elixir_libsrtp) dependency to work.","ref":"Membrane.SRTP.Encryptor.html"},{"type":"module","title":"Element options - Membrane.SRTP.Encryptor","doc":"Passed via struct `t:Membrane.SRTP.Encryptor.t/0`\n\n- `policies`  \n\n  ```\n  [ExLibSRTP.Policy.t()]\n  ```\n  \n  Default value: `[]`  \n  List of SRTP policies to use for encrypting packets.\n  See `t:ExLibSRTP.Policy.t/0` for details.","ref":"Membrane.SRTP.Encryptor.html#module-element-options"},{"type":"module","title":"Pads - Membrane.SRTP.Encryptor","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`\nDemand unit: | `nil`","ref":"Membrane.SRTP.Encryptor.html#module-pads"},{"type":"function","title":"Membrane.SRTP.Encryptor.options/0","doc":"Returns description of options available for this module","ref":"Membrane.SRTP.Encryptor.html#options/0"},{"type":"type","title":"Membrane.SRTP.Encryptor.t/0","doc":"Struct containing options for `Membrane.SRTP.Encryptor`","ref":"Membrane.SRTP.Encryptor.html#t:t/0"},{"type":"extras","title":"Membrane RTP plugin","doc":"# Membrane RTP plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_rtp_plugin.svg)](https://hex.pm/packages/membrane_rtp_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_rtp_plugin/)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_rtp_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_rtp_plugin)\n\nThis package provides bins and elements for sending and receiving RTP/SRTP and RTCP/SRTCP streams.\n\nIt is a part of [Membrane Multimedia Framework](https://membraneframework.org).","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane RTP plugin","doc":"The package can be installed by adding `membrane_rtp_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_rtp_plugin, \"~> 0.23.2\"},\n    {:ex_libsrtp, \">= 0.0.0\"} # required only if SRTP/SRTCP support is needed\n  ]\nend\n```\n\nIf SRTP/SRTCP support is needed, one has to install `libsrtp` to their system.\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"MacOS - Membrane RTP plugin","doc":"Run `brew install srtp`\n\n#","ref":"readme.html#macos"},{"type":"extras","title":"Ubuntu - Membrane RTP plugin","doc":"Run `apt install libsrtp2-dev`\n\n#","ref":"readme.html#ubuntu"},{"type":"extras","title":"Other - Membrane RTP plugin","doc":"For more details and manual installation, see [ExLibSRTP HexDocs](https://hexdocs.pm/ex_libsrtp/readme.html).","ref":"readme.html#other"},{"type":"extras","title":"Usage - Membrane RTP plugin","doc":"For usage examples, check the [RTP demo](https://github.com/membraneframework/membrane_demo/tree/master/rtp).\n\nThe docs can be found at [HexDocs](https://hexdocs.pm/membrane_rtp_plugin).","ref":"readme.html#usage"},{"type":"extras","title":"Copyright and License - Membrane RTP plugin","doc":"Copyright 2020, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_rtp_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_rtp_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Elixir.License","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2020 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}